@@ -160,6 +160,7 @@ typedef struct MESSENGER_Application
     gboolean background_task;
 
     gboolean disable_notifications;
+    gboolean play_notification_sounds;
 
     gboolean send_read_receipts;
 
@@ -277,7 +278,7 @@ typedef void (*MESSENGER_ApplicationEvent) (
 typedef void (*MESSENGER_ApplicationMessageEvent) (
   MESSENGER_Application *app,
   struct GNUNET_CHAT_Context *context,
-  const struct GNUNET_CHAT_Message *msg
+  struct GNUNET_CHAT_Message *msg
 );
 
 /**
@@ -300,7 +301,7 @@ application_call_event(MESSENGER_Application *app,
  */
 void
 application_call_sync_event(MESSENGER_Application *app,
-		                        MESSENGER_ApplicationEvent event);
+                            MESSENGER_ApplicationEvent event);
 
 /**
  * Calls a given message event with the messenger
@@ -316,7 +317,7 @@ void
 application_call_message_event(MESSENGER_Application *app,
                                MESSENGER_ApplicationMessageEvent event,
                                struct GNUNET_CHAT_Context *context,
-                               const struct GNUNET_CHAT_Message *message);
+                               struct GNUNET_CHAT_Message *message);
 
 /**
  * Lock the thread of the GNUnet scheduler
