@@ -37,10 +37,11 @@
 
 #include <gnunet/gnunet_chat_lib.h>
 #include <gnunet/gnunet_common.h>
+#include <stdio.h>
 
 static void
 _close_notification(NotifyNotification* notification,
-		                gpointer user_data)
+                    gpointer user_data)
 {
   g_assert((notification) && (user_data));
 
@@ -93,12 +94,18 @@ _show_notification(MESSENGER_Application *app,
   );
 
   notify_notification_show(notification, NULL);
+
+  if (app->settings.play_notification_sounds)
+  {
+    fprintf(stdout, "\a");
+    fflush(stdout);
+  }
 }
 
 void
 event_handle_warning(MESSENGER_Application *app,
-		                 struct GNUNET_CHAT_Context *context,
-		                 const struct GNUNET_CHAT_Message *msg)
+                     struct GNUNET_CHAT_Context *context,
+                     struct GNUNET_CHAT_Message *msg)
 {
   g_assert((app) && (msg));
 
@@ -122,7 +129,7 @@ event_handle_warning(MESSENGER_Application *app,
 
 static enum GNUNET_GenericReturnValue
 _iterate_reload_account(void *cls,
-                        UNUSED const struct GNUNET_CHAT_Handle *handle,
+                        UNUSED struct GNUNET_CHAT_Handle *handle,
                         struct GNUNET_CHAT_Account *account)
 {
   g_assert((cls) && (account));
@@ -235,7 +242,7 @@ enqueue_chat_entry_update(UI_CHAT_ENTRY_Handle *entry)
 
 static void
 _add_new_chat_entry(MESSENGER_Application *app,
-		                struct GNUNET_CHAT_Context *context)
+                    struct GNUNET_CHAT_Context *context)
 {
   g_assert((app) && (context));
 
@@ -277,8 +284,8 @@ _add_new_chat_entry(MESSENGER_Application *app,
 
 static int
 _iterate_profile_contacts(void *cls,
-			                    UNUSED struct GNUNET_CHAT_Handle *handle,
-			                    struct GNUNET_CHAT_Contact *contact)
+                          UNUSED struct GNUNET_CHAT_Handle *handle,
+                          struct GNUNET_CHAT_Contact *contact)
 {
   g_assert((cls) && (contact));
 
@@ -297,8 +304,8 @@ _iterate_profile_contacts(void *cls,
 
 static int
 _iterate_profile_groups(void *cls,
-		                    UNUSED struct GNUNET_CHAT_Handle *handle,
-		                    UNUSED struct GNUNET_CHAT_Group *group)
+                        UNUSED struct GNUNET_CHAT_Handle *handle,
+                        UNUSED struct GNUNET_CHAT_Group *group)
 {
   g_assert(cls);
 
@@ -360,7 +367,7 @@ event_update_profile(MESSENGER_Application *app)
 
 static void
 _clear_chat_entry(GtkWidget *widget,
-		              gpointer user_data)
+                  gpointer user_data)
 {
   g_assert((widget) && (user_data));
 
@@ -384,8 +391,8 @@ _clear_chat_entry(GtkWidget *widget,
 
 static int
 _cleanup_profile_contacts(void *cls,
-			                    UNUSED struct GNUNET_CHAT_Handle *handle,
-			                    struct GNUNET_CHAT_Contact *contact)
+                          UNUSED struct GNUNET_CHAT_Handle *handle,
+                          struct GNUNET_CHAT_Contact *contact)
 {
   if (contact)
     contact_destroy_info(contact);
@@ -394,8 +401,8 @@ _cleanup_profile_contacts(void *cls,
 
 static int
 _cleanup_profile_files(void *cls,
-			                    UNUSED struct GNUNET_CHAT_Handle *handle,
-			                    struct GNUNET_CHAT_File *file)
+                       UNUSED struct GNUNET_CHAT_Handle *handle,
+                       struct GNUNET_CHAT_File *file)
 {
   if (file)
     file_destroy_info(file);
@@ -428,14 +435,14 @@ event_cleanup_profile(MESSENGER_Application *app)
 
 void
 event_select_profile(MESSENGER_Application *app,
-		                 struct GNUNET_CHAT_Context *context,
-		                 const struct GNUNET_CHAT_Message *msg)
+                     struct GNUNET_CHAT_Context *context,
+                     struct GNUNET_CHAT_Message *msg)
 {
   g_assert((app) && (!context) && (msg));
 
   CHAT_MESSENGER_Handle *chat = &(app->chat.messenger);
 
-  const struct GNUNET_CHAT_Account *account = GNUNET_CHAT_message_get_account(msg);
+  struct GNUNET_CHAT_Account *account = GNUNET_CHAT_message_get_account(msg);
 
   if (GNUNET_CHAT_KIND_CREATED_ACCOUNT == GNUNET_CHAT_message_get_kind(msg))
     GNUNET_CHAT_connect(chat->handle, account);
@@ -465,8 +472,8 @@ _delayed_context_drop(gpointer user_data)
 
 void
 event_update_chats(MESSENGER_Application *app,
-		               struct GNUNET_CHAT_Context *context,
-		               const struct GNUNET_CHAT_Message *msg)
+                   struct GNUNET_CHAT_Context *context,
+                   struct GNUNET_CHAT_Message *msg)
 {
   g_assert((app) && (context) && (msg));
 
@@ -526,8 +533,8 @@ _update_contact_context(struct GNUNET_CHAT_Contact *contact)
 
 void
 event_presence_contact(MESSENGER_Application *app,
-		                   struct GNUNET_CHAT_Context *context,
-		                   const struct GNUNET_CHAT_Message *msg)
+                       struct GNUNET_CHAT_Context *context,
+                       struct GNUNET_CHAT_Message *msg)
 {
   g_assert((app) && (context) && (msg));
 
@@ -591,11 +598,12 @@ event_presence_contact(MESSENGER_Application *app,
       "presence.online"
     );
 
-  struct GNUNET_TIME_Absolute timestamp = GNUNET_CHAT_message_get_timestamp(
+  char time [20];
+  time_t timestamp = GNUNET_CHAT_message_get_timestamp(
     msg
   );
 
-  const char *time = GNUNET_STRINGS_absolute_time_to_string(timestamp);
+  strftime(time, 20, "%Y-%m-%d %H:%M:%S", localtime(&timestamp));
 
   ui_label_set_text(message->text_label, text);
   ui_label_set_text(message->timestamp_label, time);
@@ -612,8 +620,8 @@ event_presence_contact(MESSENGER_Application *app,
 
 void
 event_update_contacts(UNUSED MESSENGER_Application *app,
-		                  struct GNUNET_CHAT_Context *context,
-		                  const struct GNUNET_CHAT_Message *msg)
+                      struct GNUNET_CHAT_Context *context,
+                      struct GNUNET_CHAT_Message *msg)
 {
   g_assert((app) && (msg));
 
@@ -643,7 +651,7 @@ event_update_contacts(UNUSED MESSENGER_Application *app,
 
 static void
 _event_invitation_accept_click(UNUSED GtkButton *button,
-			                         gpointer user_data)
+                               gpointer user_data)
 {
   g_assert(user_data);
 
@@ -670,7 +678,7 @@ _event_invitation_deny_click(UNUSED GtkButton *button,
 void
 event_invitation(MESSENGER_Application *app,
                  struct GNUNET_CHAT_Context *context,
-                 const struct GNUNET_CHAT_Message *msg)
+                 struct GNUNET_CHAT_Message *msg)
 {
   g_assert((app) && (context) && (msg));
 
@@ -686,10 +694,10 @@ event_invitation(MESSENGER_Application *app,
     return;
 
   if (app->settings.delete_invitations_delay > 0)
-    GNUNET_CHAT_message_delete(msg, GNUNET_TIME_relative_multiply(
-      GNUNET_TIME_relative_get_second_(),
+    GNUNET_CHAT_message_delete(
+      msg,
       app->settings.delete_invitations_delay
-    ));
+    );
 
   const int sent = GNUNET_CHAT_message_is_sent(msg);
 
@@ -699,11 +707,11 @@ event_invitation(MESSENGER_Application *app,
   UI_MESSAGE_Handle *message = ui_message_new(app, UI_MESSAGE_STATUS);
   ui_message_update(message, app, msg);
 
-  const struct GNUNET_CHAT_Contact *sender = GNUNET_CHAT_message_get_sender(
+  struct GNUNET_CHAT_Contact *sender = GNUNET_CHAT_message_get_sender(
     msg
   );
 
-  const struct GNUNET_CHAT_Contact *recipient = GNUNET_CHAT_message_get_recipient(
+  struct GNUNET_CHAT_Contact *recipient = GNUNET_CHAT_message_get_recipient(
     msg
   );
 
@@ -754,7 +762,7 @@ event_invitation(MESSENGER_Application *app,
 void
 event_receive_message(MESSENGER_Application *app,
                       struct GNUNET_CHAT_Context *context,
-                      const struct GNUNET_CHAT_Message *msg)
+                      struct GNUNET_CHAT_Message *msg)
 {
   g_assert((app) && (context) && (msg));
 
@@ -766,10 +774,10 @@ event_receive_message(MESSENGER_Application *app,
   const int sent = GNUNET_CHAT_message_is_sent(msg);
 
   if ((sent) && (app->settings.auto_delete_delay > 0))
-    GNUNET_CHAT_message_delete(msg, GNUNET_TIME_relative_multiply(
-      GNUNET_TIME_relative_get_second_(),
+    GNUNET_CHAT_message_delete(
+      msg,
       app->settings.auto_delete_delay
-    ));
+    );
 
   const gchar *text = GNUNET_CHAT_message_get_text(msg);
 
@@ -793,25 +801,26 @@ event_receive_message(MESSENGER_Application *app,
     file_add_ui_message_to_info(file, message);
 
     if (app->settings.delete_files_delay > 0)
-      GNUNET_CHAT_message_delete(msg, GNUNET_TIME_relative_multiply(
-        GNUNET_TIME_relative_get_second_(),
+      GNUNET_CHAT_message_delete(
+        msg,
         app->settings.delete_files_delay
-      ));
+      );
   }
 
   ui_message_update(message, app, msg);
 
-  const struct GNUNET_CHAT_Contact *contact = GNUNET_CHAT_message_get_sender(
+  struct GNUNET_CHAT_Contact *contact = GNUNET_CHAT_message_get_sender(
     msg
   );
 
   ui_message_set_contact(message, contact);
 
-  struct GNUNET_TIME_Absolute timestamp = GNUNET_CHAT_message_get_timestamp(
+  char time [20];
+  time_t timestamp = GNUNET_CHAT_message_get_timestamp(
     msg
   );
 
-  const char *time = GNUNET_STRINGS_absolute_time_to_string(timestamp);
+  strftime(time, 20, "%Y-%m-%d %H:%M:%S", localtime(&timestamp));
 
   if ((!ui_messenger_is_context_active(&(app->ui.messenger), context)) &&
       (GNUNET_YES == GNUNET_CHAT_message_is_recent(msg)) &&
@@ -837,11 +846,11 @@ skip_message:
 static void
 _event_update_tag_message_state(MESSENGER_Application *app,
                                 struct GNUNET_CHAT_Context *context,
-                                const struct GNUNET_CHAT_Message *msg)
+                                struct GNUNET_CHAT_Message *msg)
 {
   g_assert((msg) && (GNUNET_CHAT_KIND_TAG == GNUNET_CHAT_message_get_kind(msg)));
 
-  const struct GNUNET_CHAT_Message *target;
+  struct GNUNET_CHAT_Message *target;
   target = GNUNET_CHAT_message_get_target(msg);
 
   if (!target)
@@ -886,7 +895,7 @@ _event_update_tag_message_state(MESSENGER_Application *app,
 void
 event_delete_message(MESSENGER_Application *app,
                      struct GNUNET_CHAT_Context *context,
-                     const struct GNUNET_CHAT_Message *msg)
+                     struct GNUNET_CHAT_Message *msg)
 {
   g_assert((app) && (context) && (msg));
 
@@ -924,13 +933,13 @@ event_delete_message(MESSENGER_Application *app,
 void
 event_tag_message(MESSENGER_Application *app,
                   struct GNUNET_CHAT_Context *context,
-                  const struct GNUNET_CHAT_Message *msg)
+                  struct GNUNET_CHAT_Message *msg)
 {
   g_assert((app) && (context) && (msg));
 
   UI_CHAT_ENTRY_Handle *handle = GNUNET_CHAT_context_get_user_pointer(context);
 
-  const struct GNUNET_CHAT_Message *target = GNUNET_CHAT_message_get_target(msg);
+  struct GNUNET_CHAT_Message *target = GNUNET_CHAT_message_get_target(msg);
 
   _event_update_tag_message_state(app, context, msg);
 
@@ -983,7 +992,7 @@ event_update_attributes(MESSENGER_Application *app)
 
   CHAT_MESSENGER_Handle *chat = &(app->chat.messenger);
 
-  const struct GNUNET_CHAT_Account *account = GNUNET_CHAT_get_connected(
+  struct GNUNET_CHAT_Account *account = GNUNET_CHAT_get_connected(
     chat->handle
   );
 
@@ -1000,7 +1009,7 @@ event_update_attributes(MESSENGER_Application *app)
 void
 event_discourse(MESSENGER_Application *app,
                 struct GNUNET_CHAT_Context *context,
-                const struct GNUNET_CHAT_Message *msg)
+                struct GNUNET_CHAT_Message *msg)
 {
   g_assert((app) && (context) && (msg));
 
@@ -1028,7 +1037,7 @@ event_discourse(MESSENGER_Application *app,
 void
 event_discourse_data(MESSENGER_Application *app,
                      struct GNUNET_CHAT_Context *context,
-                     const struct GNUNET_CHAT_Message *msg)
+                     struct GNUNET_CHAT_Message *msg)
 {
   g_assert((app) && (context) && (msg));
 
