@@ -33,13 +33,11 @@
 #include "../ui.h"
 
 #include <gnunet/gnunet_chat_lib.h>
-#include <gnunet/gnunet_common.h>
-#include <gnunet/gnunet_time_lib.h>
 #include <string.h>
 
 static void
 handle_contact_edit_button_click(UNUSED GtkButton *button,
-				                         gpointer user_data)
+                                 gpointer user_data)
 {
   g_assert(user_data);
 
@@ -94,7 +92,7 @@ skip_change_name:
 
 static void
 handle_contact_name_entry_activate(UNUSED GtkEntry *entry,
-				                           gpointer user_data)
+                                   gpointer user_data)
 {
   g_assert(user_data);
 
@@ -168,8 +166,7 @@ _cb_file_upload(void *cls,
     GNUNET_CHAT_set_attribute(
       app->chat.messenger.handle,
       GNUNET_CHAT_ATTRIBUTE_AVATAR,
-      uri_string,
-      GNUNET_TIME_relative_get_forever_()
+      uri_string
     );
 
     GNUNET_free(uri_string);
@@ -253,6 +250,17 @@ handle_share_attributes_button_click(UNUSED GtkButton *button,
   _contact_info_switch_stack_to(handle, handle->sharing_box);
 }
 
+static void
+handle_list_tags_button_click(UNUSED GtkButton *button,
+                              gpointer user_data)
+{
+  g_assert(user_data);
+
+  struct UI_CONTACT_INFO_Handle *handle = (UI_CONTACT_INFO_Handle*) user_data;
+
+  _contact_info_switch_stack_to(handle, handle->tags_box);
+}
+
 static void
 handle_block_button_click(UNUSED GtkButton *button,
                           gpointer user_data)
@@ -297,7 +305,7 @@ handle_unblock_button_click(UNUSED GtkButton *button,
 
 static void
 handle_open_chat_button_click(UNUSED GtkButton *button,
-			                        gpointer user_data)
+                              gpointer user_data)
 {
   g_assert(user_data);
 
@@ -342,7 +350,7 @@ close_dialog:
 
 static void
 handle_back_button_click(UNUSED GtkButton *button,
-			                   gpointer user_data)
+                         gpointer user_data)
 {
   g_assert(user_data);
 
@@ -664,6 +672,50 @@ cb_contact_info_shared_attributes(void *cls,
   return GNUNET_YES;
 }
 
+static enum GNUNET_GenericReturnValue
+cb_contact_info_contact_tags(void *cls,
+                             struct GNUNET_CHAT_Contact *contact,
+                             const char *tag)
+{
+  g_assert((cls) && (contact) && (tag));
+
+  UI_CONTACT_INFO_Handle *handle = (UI_CONTACT_INFO_Handle*) cls;
+  GtkTreeModel *model = GTK_TREE_MODEL(handle->tags_list);
+  GtkTreeIter iter;
+
+  GValue val_tag = G_VALUE_INIT;
+
+  gboolean valid = gtk_tree_model_get_iter_first(model, &iter);
+  gboolean match = FALSE;
+
+  while (valid)
+  {
+    gtk_tree_model_get_value(model, &iter, 0, &val_tag);
+    
+    if (0 == strcmp(g_value_get_string(&val_tag), tag))
+      match = TRUE;
+
+    g_value_unset(&val_tag);
+
+    if (match)
+      break;
+
+    valid = gtk_tree_model_iter_next(model, &iter);
+  }
+
+  if (!match)
+    gtk_list_store_insert_with_values(
+      handle->tags_list,
+      NULL,
+      -1,
+      0,
+      tag,
+      -1
+    );
+
+  return GNUNET_YES;
+}
+
 static void
 handle_value_renderer_edit(GtkCellRendererText *renderer,
                            char *path,
@@ -698,7 +750,7 @@ handle_value_renderer_edit(GtkCellRendererText *renderer,
   if ((new_text) && (strlen(new_text)))
   {
     application_chat_lock(handle->app);
-    GNUNET_CHAT_set_attribute(chat, name, new_text, GNUNET_TIME_relative_get_forever_());
+    GNUNET_CHAT_set_attribute(chat, name, new_text);
     application_chat_unlock(handle->app);
 
     gtk_list_store_set(handle->attributes_list, &iter, 1, new_text, -1);
@@ -748,7 +800,7 @@ handle_add_attribute_button_click(UNUSED GtkButton *button,
   if ((name) && (value))
   {
     application_chat_lock(handle->app);
-    GNUNET_CHAT_set_attribute(chat, name, value, GNUNET_TIME_relative_get_forever_());
+    GNUNET_CHAT_set_attribute(chat, name, value);
     application_chat_unlock(handle->app);
 
     gtk_list_store_insert_with_values(
@@ -768,8 +820,8 @@ handle_add_attribute_button_click(UNUSED GtkButton *button,
 }
 
 static void
-handle_attribute_value_entry_activate(UNUSED GtkEntry *entry,
-				                              gpointer user_data)
+handle_attribute_entry_activate(UNUSED GtkEntry *entry,
+                                gpointer user_data)
 {
   g_assert(user_data);
 
@@ -827,6 +879,114 @@ handle_share_renderer_toggle(GtkCellRendererToggle *renderer,
   g_value_unset(&value_shared);
 }
 
+static void
+handle_tag_tree_selection_changed(GtkTreeSelection *selection,
+                                  gpointer user_data)
+{
+  g_assert((selection) && (user_data));
+
+  GtkWidget *widget = GTK_WIDGET(user_data);
+
+  const gboolean selected = gtk_tree_selection_get_selected(
+    selection, NULL, NULL);
+
+  gtk_widget_set_sensitive(widget, selected);
+}
+
+static void
+handle_tag_entry_changed(GtkEditable *editable,
+                         gpointer user_data)
+{
+  g_assert((editable) && (user_data));
+
+  GtkEntry *entry = GTK_ENTRY(editable);
+  GtkWidget *target = GTK_WIDGET(user_data);
+
+  const gchar *text = gtk_entry_get_text(entry);
+
+  gtk_widget_set_sensitive(target, (text) && (strlen(text)));
+}
+
+static void
+handle_add_tag_button_click(UNUSED GtkButton *button,
+                            gpointer user_data)
+{
+  g_assert(user_data);
+
+  UI_CONTACT_INFO_Handle *handle = (UI_CONTACT_INFO_Handle*) user_data;
+
+  struct GNUNET_CHAT_Handle *chat = handle->app->chat.messenger.handle;
+
+  if (!chat)
+    return;
+
+  const gchar *tag = gtk_entry_get_text(handle->tag_name_entry);
+
+  if (tag)
+  {
+    application_chat_lock(handle->app);
+    GNUNET_CHAT_contact_tag(handle->contact, tag);
+    application_chat_unlock(handle->app);
+
+    gtk_list_store_insert_with_values(
+      handle->tags_list,
+      NULL,
+      -1,
+      0,
+      tag,
+      -1
+    );
+  }
+
+  gtk_entry_set_text(handle->tag_name_entry, "");
+}
+
+static void
+handle_remove_tag_button_click(UNUSED GtkButton *button,
+                               gpointer user_data)
+{
+  g_assert(user_data);
+
+  UI_CONTACT_INFO_Handle *handle = (UI_CONTACT_INFO_Handle*) user_data;
+  GtkTreeIter iter;
+
+  if (!gtk_tree_selection_get_selected(handle->tags_tree_selection, NULL, &iter))
+    return;
+
+  struct GNUNET_CHAT_Handle *chat = handle->app->chat.messenger.handle;
+
+  if (!chat)
+    return;
+
+  GValue value = G_VALUE_INIT;
+  gtk_tree_model_get_value(GTK_TREE_MODEL(handle->tags_list), &iter, 0, &value);
+
+  const gchar *tag = g_value_get_string(&value);
+
+  if (tag)
+  {
+    application_chat_lock(handle->app);
+    GNUNET_CHAT_contact_untag(handle->contact, tag);
+    application_chat_unlock(handle->app);
+
+    gtk_list_store_remove(
+      handle->tags_list,
+      &iter
+    );
+  }
+}
+
+static void
+handle_tag_entry_activate(UNUSED GtkEntry *entry,
+                          gpointer user_data)
+{
+  g_assert(user_data);
+
+  UI_CONTACT_INFO_Handle *handle = (UI_CONTACT_INFO_Handle*) user_data;
+
+  handle_add_tag_button_click(handle->add_tag_button, handle);
+}
+
 void
 ui_contact_info_dialog_init(MESSENGER_Application *app,
                             UI_CONTACT_INFO_Handle *handle)
@@ -940,6 +1100,17 @@ ui_contact_info_dialog_init(MESSENGER_Application *app,
     handle
   );
 
+  handle->list_tags_button = GTK_BUTTON(
+    gtk_builder_get_object(handle->builder, "list_tags_button")
+  );
+
+  g_signal_connect(
+    handle->list_tags_button,
+    "clicked",
+    G_CALLBACK(handle_list_tags_button_click),
+    handle
+  );
+
   handle->block_stack = GTK_STACK(
     gtk_builder_get_object(handle->builder, "block_stack")
   );
@@ -1056,7 +1227,7 @@ ui_contact_info_dialog_init(MESSENGER_Application *app,
   g_signal_connect(
     handle->attribute_value_entry,
     "activate",
-    G_CALLBACK(handle_attribute_value_entry_activate),
+    G_CALLBACK(handle_attribute_entry_activate),
     handle
   );
 
@@ -1090,6 +1261,73 @@ ui_contact_info_dialog_init(MESSENGER_Application *app,
     handle
   );
 
+  handle->tags_box = GTK_WIDGET(
+    gtk_builder_get_object(handle->builder, "tags_box")
+  );
+
+  handle->tags_tree = GTK_TREE_VIEW(
+    gtk_builder_get_object(handle->builder, "tags_tree")
+  );
+
+  handle->tags_tree_selection = GTK_TREE_SELECTION(
+    gtk_builder_get_object(handle->builder, "tags_tree_selection")
+  );
+
+  handle->tags_list = GTK_LIST_STORE(
+    gtk_builder_get_object(handle->builder, "tags_list")
+  );
+
+  handle->new_tag_box = GTK_WIDGET(
+    gtk_builder_get_object(handle->builder, "new_tag_box")
+  );
+
+  handle->tag_name_entry = GTK_ENTRY(
+    gtk_builder_get_object(handle->builder, "tag_name_entry")
+  );
+
+  handle->add_tag_button = GTK_BUTTON(
+    gtk_builder_get_object(handle->builder, "add_tag_button")
+  );
+
+  handle->remove_tag_button = GTK_BUTTON(
+    gtk_builder_get_object(handle->builder, "remove_tag_button")
+  );
+
+  g_signal_connect(
+    handle->tags_tree_selection,
+    "changed",
+    G_CALLBACK(handle_tag_tree_selection_changed),
+    handle->remove_tag_button
+  );
+
+  g_signal_connect(
+    handle->tag_name_entry,
+    "changed",
+    G_CALLBACK(handle_tag_entry_changed),
+    handle->add_tag_button
+  );
+
+  g_signal_connect(
+    handle->tag_name_entry,
+    "activate",
+    G_CALLBACK(handle_tag_entry_activate),
+    handle
+  );
+
+  g_signal_connect(
+    handle->add_tag_button,
+    "clicked",
+    G_CALLBACK(handle_add_tag_button_click),
+    handle
+  );
+
+  g_signal_connect(
+    handle->remove_tag_button,
+    "clicked",
+    G_CALLBACK(handle_remove_tag_button_click),
+    handle
+  );
+
   handle->back_button = GTK_BUTTON(
     gtk_builder_get_object(handle->builder, "back_button")
   );
@@ -1136,7 +1374,7 @@ _contact_info_update(UI_CONTACT_INFO_Handle *handle,
 
 static void
 _account_info_update(UI_CONTACT_INFO_Handle *handle,
-                     const struct GNUNET_CHAT_Account *account)
+                     struct GNUNET_CHAT_Account *account)
 {
   g_assert(handle);
 
@@ -1167,7 +1405,7 @@ ui_contact_info_dialog_update(UI_CONTACT_INFO_Handle *handle,
     _contact_info_update(handle, contact);
   else
   {
-    const struct GNUNET_CHAT_Account *account = GNUNET_CHAT_get_connected(
+    struct GNUNET_CHAT_Account *account = GNUNET_CHAT_get_connected(
       handle->app->chat.messenger.handle
     );
 
@@ -1239,6 +1477,16 @@ ui_contact_info_dialog_update(UI_CONTACT_INFO_Handle *handle,
     !editable
   );
 
+  gtk_widget_set_sensitive(
+    GTK_WIDGET(handle->list_tags_button),
+    !editable
+  );
+
+  gtk_widget_set_sensitive(
+    GTK_WIDGET(handle->tag_name_entry),
+    !editable
+  );
+
   gtk_widget_set_sensitive(
     GTK_WIDGET(handle->block_button),
     !editable
@@ -1259,6 +1507,16 @@ ui_contact_info_dialog_update(UI_CONTACT_INFO_Handle *handle,
     !editable
   );
 
+  gtk_widget_set_visible(
+    GTK_WIDGET(handle->list_tags_button),
+    !editable
+  );
+
+  gtk_widget_set_visible(
+    GTK_WIDGET(handle->new_tag_box),
+    !editable
+  );
+
   gtk_stack_set_visible_child(
     handle->block_stack,
     GNUNET_YES == GNUNET_CHAT_contact_is_blocked(contact)?
@@ -1273,6 +1531,7 @@ ui_contact_info_dialog_update(UI_CONTACT_INFO_Handle *handle,
 
   gtk_list_store_clear(handle->attributes_list);
   gtk_list_store_clear(handle->sharing_list);
+  gtk_list_store_clear(handle->tags_list);
 
   if (editable)
     GNUNET_CHAT_get_attributes(
@@ -1300,6 +1559,12 @@ ui_contact_info_dialog_update(UI_CONTACT_INFO_Handle *handle,
       cb_contact_info_shared_attributes,
       handle
     );
+
+    GNUNET_CHAT_contact_iterate_tags(
+      contact,
+      cb_contact_info_contact_tags,
+      handle
+    );
   }
 
   struct GNUNET_CHAT_Context *context = GNUNET_CHAT_contact_get_context(
