@@ -25,9 +25,7 @@
 #include "discourse.h"
 
 #include <glib-2.0/glib.h>
-#include <gnunet/gnunet_common.h>
 #include <gnunet/gnunet_chat_lib.h>
-#include <gnunet/gnunet_time_lib.h>
 
 #include "account_entry.h"
 #include "discourse_panel.h"
@@ -42,7 +40,7 @@
 
 static void
 handle_back_button_click(UNUSED GtkButton *button,
-			                   gpointer user_data)
+                         gpointer user_data)
 {
   g_assert(user_data);
 
@@ -52,7 +50,7 @@ handle_back_button_click(UNUSED GtkButton *button,
 
 static void
 handle_details_button_click(UNUSED GtkButton *button,
-			                      gpointer user_data)
+                            gpointer user_data)
 {
   g_assert(user_data);
 
@@ -92,7 +90,7 @@ _update_microphone_icon(UI_DISCOURSE_Handle *handle)
 
 static void
 handle_microphone_button_click(UNUSED GtkButton *button,
-			                         gpointer user_data)
+                               gpointer user_data)
 {
   g_assert(user_data);
 
@@ -284,7 +282,7 @@ _update_call_button(UI_DISCOURSE_Handle *handle)
 
 static void
 handle_call_start_button_click(UNUSED GtkButton *button,
-			                         gpointer user_data)
+                               gpointer user_data)
 {
   g_assert(user_data);
 
@@ -309,7 +307,7 @@ handle_call_start_button_click(UNUSED GtkButton *button,
 
 static void
 handle_call_stop_button_click(UNUSED GtkButton *button,
-			                        gpointer user_data)
+                              gpointer user_data)
 {
   g_assert(user_data);
 
@@ -341,7 +339,7 @@ handle_call_stop_button_click(UNUSED GtkButton *button,
 
 static void
 handle_window_destroy(UNUSED GtkWidget *window,
-		                  gpointer user_data)
+                      gpointer user_data)
 {
   g_assert(user_data);
 
@@ -545,7 +543,7 @@ ui_discourse_window_init(MESSENGER_Application *app,
 
 static enum GNUNET_GenericReturnValue
 append_discourse_members_to_list(void *cls,
-                                 UNUSED const struct GNUNET_CHAT_Discourse *discourse,
+                                 UNUSED struct GNUNET_CHAT_Discourse *discourse,
                                  struct GNUNET_CHAT_Contact *contact)
 {
   g_assert((cls) && (contact));
@@ -573,7 +571,7 @@ append_discourses_members(void *cls,
 
 static enum GNUNET_GenericReturnValue
 append_group_contacts(void *cls,
-                      UNUSED const struct GNUNET_CHAT_Group *group,
+                      UNUSED struct GNUNET_CHAT_Group *group,
                       struct GNUNET_CHAT_Contact *contact)
 {
   g_assert((cls) && (contact));
@@ -591,7 +589,7 @@ struct IterateDiscourseClosure {
 
 static enum GNUNET_GenericReturnValue
 iterate_ui_discourse_update_discourse_members(void *cls,
-                                              const struct GNUNET_CHAT_Discourse *discourse,
+                                              struct GNUNET_CHAT_Discourse *discourse,
                                               struct GNUNET_CHAT_Contact *contact)
 {
   struct IterateDiscourseClosure *closure = (
@@ -651,7 +649,7 @@ struct IterateDiscourseVideoClosure {
 
 static enum GNUNET_GenericReturnValue
 iterate_ui_discourse_update_discourse_video(void *cls,
-                                            const struct GNUNET_CHAT_Discourse *discourse,
+                                            struct GNUNET_CHAT_Discourse *discourse,
                                             struct GNUNET_CHAT_Contact *contact)
 {
   g_assert((cls) && (discourse) && (contact));
@@ -757,7 +755,7 @@ _discourse_update_members(UI_DISCOURSE_Handle *handle)
 
 static enum GNUNET_GenericReturnValue
 iterate_ui_discourse_update_group_contacts(void *cls,
-                                           UNUSED const struct GNUNET_CHAT_Group *group,
+                                           UNUSED struct GNUNET_CHAT_Group *group,
                                            struct GNUNET_CHAT_Contact *contact)
 {
   struct IterateDiscourseClosure *closure = (
@@ -840,7 +838,7 @@ iterate_ui_discourse_search_context_discourses(void *cls,
 
   struct GNUNET_CHAT_Discourse **discourses = (struct GNUNET_CHAT_Discourse**) cls;
 
-  const struct GNUNET_ShortHashCode *id = GNUNET_CHAT_discourse_get_id(discourse);
+  const struct GNUNET_CHAT_DiscourseId *id = GNUNET_CHAT_discourse_get_id(discourse);
 
   if (0 == GNUNET_memcmp(id, get_voice_discourse_id()))
     discourses[0] = discourse;
